/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

import QtQuick 2.15
import StudioControls 1.0 as StudioControls

Item {
    id: wrapper

    property alias decimals: spinBox.decimals
    property alias hasSlider: spinBox.hasSlider
    property alias value: spinBox.realValue
    property alias minimumValue: spinBox.realFrom
    property alias maximumValue: spinBox.realTo
    property alias stepSize: spinBox.realStepSize
    property alias sliderIndicatorVisible: spinBox.sliderIndicatorVisible
    property alias hover: spinBox.hover

    property alias pixelsPerUnit: spinBox.pixelsPerUnit

    signal valueModified
    signal dragStarted
    signal indicatorPressed

    width: 90
    implicitHeight: spinBox.height

    onFocusChanged: restoreCursor()

    StudioControls.RealSpinBox {
        id: spinBox

        __devicePixelRatio: devicePixelRatio()

        onDragStarted: {
            hideCursor()
            wrapper.dragStarted()
        }
        onDragEnded: restoreCursor()
        onDragging: holdCursorInPlace()
        onIndicatorPressed: wrapper.indicatorPressed()

        property bool hasSlider: spinBox.sliderIndicatorVisible

        width: wrapper.width
        actionIndicatorVisible: false

        realFrom: 0.0
        realTo: 1.0
        realStepSize: 0.1
        decimals: 2

        onRealValueModified: wrapper.valueModified()
    }
}
