/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_RULESEVALUATIONCONTEXT_H
#define QBS_RULESEVALUATIONCONTEXT_H

#include <language/forward_decls.h>
#include <logging/logger.h>

#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

#include <QtScript/qscriptprogram.h>
#include <QtScript/qscriptvalue.h>

namespace qbs {
namespace Internal {
class ProgressObserver;
class ScriptEngine;

class RulesEvaluationContext
{
public:
    RulesEvaluationContext(Logger logger);
    ~RulesEvaluationContext();

    class Scope
    {
    public:
        Scope(RulesEvaluationContext *evalContext);
        ~Scope();

    private:
        RulesEvaluationContext * const m_evalContext;
    };

    ScriptEngine *engine() const { return m_engine; }
    QScriptValue scope() const { return m_scope; }

    void setObserver(ProgressObserver *observer) { m_observer = observer; }
    ProgressObserver *observer() const { return m_observer; }
    void initializeObserver(const QString &description, int maximumProgress);
    void incrementProgressValue();
    void checkForCancelation();

private:
    friend class Scope;

    void initScope();
    void cleanupScope();

    Logger m_logger;
    ScriptEngine * const m_engine;
    ProgressObserver *m_observer;
    unsigned int m_initScopeCalls;
    QScriptValue m_scope;
    QScriptValue m_prepareScriptScope;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_RULESEVALUATIONCONTEXT_H
